@@ -210,7 +210,7 @@ EOAPI Eina_Slice efl_io_buffer_slice_get(const Eo *obj);
  * The returned memory must be freed with eina_binbuf_free().
  *
  * On failure, for example a read-only backing store was adopted with
- * @ref efl_io_buffer_adopt_readonly, NULL is returned.
+ * @ref efl_io_buffer_adopt_readonly, @c NULL is returned.
  *
  * @param[in] obj The object.
  *
@@ -218,7 +218,7 @@ EOAPI Eina_Slice efl_io_buffer_slice_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffer
  */
-EOAPI Eina_Binbuf *efl_io_buffer_binbuf_steal(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Binbuf *efl_io_buffer_binbuf_steal(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 EWAPI extern const Efl_Event_Description _EFL_IO_BUFFER_EVENT_POSITION_READ_CHANGED;
 
@@ -239,7 +239,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFER_EVENT_POSITION_WRITE_CHA
 EWAPI extern const Efl_Event_Description _EFL_IO_BUFFER_EVENT_REALLOCATED;
 
 /** Notifies the internal buffer was reallocated, thus whatever was returned by
- * @ref efl_io_buffer_slice_get becomes invalid
+ * @ref efl_io_buffer_slice_get becomes invalid.
  *
  * @ingroup Efl_Io_Buffer
  */
