@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Legacy;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The bg (background) widget is used for setting (solid) background
  * decorations
@@ -26,5 +27,6 @@ typedef Eo Efl_Ui_Legacy;
 #define EFL_UI_LEGACY_INTERFACE efl_ui_legacy_interface_get()
 
 EWAPI const Efl_Class *efl_ui_legacy_interface_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
