@@ -13,13 +13,12 @@ typedef Eo Efl_Ui_Slider_Interval;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief An interval slider.
  *
  * This is a slider with two indicators.
  *
- * @since 1.21
- *
  * @ingroup Efl_Ui_Slider_Interval
  */
 #define EFL_UI_SLIDER_INTERVAL_CLASS efl_ui_slider_interval_class_get()
@@ -33,8 +32,6 @@ EWAPI const Efl_Class *efl_ui_slider_interval_class_get(void);
  * @param[in] from interval minimum value
  * @param[in] to interval maximum value
  *
- * @since 1.21
- *
  * @ingroup Efl_Ui_Slider_Interval
  */
 EOAPI void efl_ui_slider_interval_value_set(Eo *obj, double from, double to);
@@ -46,10 +43,27 @@ EOAPI void efl_ui_slider_interval_value_set(Eo *obj, double from, double to);
  * @param[out] from interval minimum value
  * @param[out] to interval maximum value
  *
- * @since 1.21
- *
  * @ingroup Efl_Ui_Slider_Interval
  */
 EOAPI void efl_ui_slider_interval_value_get(const Eo *obj, double *from, double *to);
 
+EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_INTERVAL_EVENT_SLIDER_DRAG_START;
+
+/** Called when a slider drag operation has started. This means a @c press
+ * event has been received on the slider thumb but not the @c unpress.
+ *
+ * @ingroup Efl_Ui_Slider_Interval
+ */
+#define EFL_UI_SLIDER_INTERVAL_EVENT_SLIDER_DRAG_START (&(_EFL_UI_SLIDER_INTERVAL_EVENT_SLIDER_DRAG_START))
+
+EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_INTERVAL_EVENT_SLIDER_DRAG_STOP;
+
+/** Called when a slider drag operation has finished. This means an @c unpress
+ * event has been received on the slider thumb.
+ *
+ * @ingroup Efl_Ui_Slider_Interval
+ */
+#define EFL_UI_SLIDER_INTERVAL_EVENT_SLIDER_DRAG_STOP (&(_EFL_UI_SLIDER_INTERVAL_EVENT_SLIDER_DRAG_STOP))
+#endif /* EFL_BETA_API_SUPPORT */
+
 #endif
