@@ -118,8 +118,7 @@
  * @li password - "on" or "off". This is used to specifically turn replacing chars with the replacement char (i.e password mode) on and off.
  *
  * @warning We don't guarantee any proper results if you create a Textblock
- * object
- * without setting the evas engine.
+ * object without setting the evas engine.
  *
  * @todo put here some usage examples
  *
@@ -138,7 +137,7 @@ typedef Eo Evas_Textblock;
  * @see evas_textblock_style_set()
  */
 
-typedef struct _Efl_Canvas_Text_Style             Evas_Textblock_Style;
+typedef struct _Efl_Canvas_Textblock_Style             Evas_Textblock_Style;
 
 /**
  * @typedef Evas_Textblock_Cursor
@@ -147,7 +146,7 @@ typedef struct _Efl_Canvas_Text_Style             Evas_Textblock_Style;
  * @see evas_object_textblock_cursor_new
  *
  */
-typedef struct _Efl_Text_Cursor_Cursor       Evas_Textblock_Cursor;
+typedef struct _Efl_Text_Cursor_Handle       Evas_Textblock_Cursor;
 
 /**
  * @typedef Evas_Object_Textblock_Node_Format
@@ -562,7 +561,7 @@ EAPI Eina_List                               *evas_textblock_cursor_range_geomet
 
 /**
  * Get the simple geometry of a range.
- * The simple geometry is the geomtry in which rectangles in middle
+ * The simple geometry is the geometry in which rectangles in middle
  * lines of range are merged into one big rectangle.
  * @since 1.13
  *
@@ -573,10 +572,6 @@ EAPI Eina_List                               *evas_textblock_cursor_range_geomet
 EAPI Eina_Iterator                               *evas_textblock_cursor_range_simple_geometry_get(const Evas_Textblock_Cursor *cur1, const Evas_Textblock_Cursor *cur2) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(1, 2);
 
 /**
- * Get the geometry of ?
- *
- * @param cur one side of the range.
- * @param cur2 other side of the range.
  */
 EAPI Eina_Bool                                evas_textblock_cursor_format_item_geometry_get(const Evas_Textblock_Cursor *cur, Evas_Coord *cx, Evas_Coord *cy, Evas_Coord *cw, Evas_Coord *ch) EINA_ARG_NONNULL(1);
 
@@ -661,7 +656,7 @@ EAPI Eina_Bool evas_textblock_cursor_word_end(Evas_Textblock_Cursor *obj);
  */
 
 /**
- * @ingroup Evas_Object_Textblock
+ * @addtogroup Evas_Object_Textblock
  *
  * @{
  */
@@ -921,7 +916,7 @@ EAPI int evas_textblock_cursor_text_prepend(Evas_Textblock_Cursor *cur, const ch
  *
  * @param[in] ch The charset name.
  *
- * @ingroup Efl_Canvas_Text
+ * @ingroup Efl_Canvas_Textblock
  */
 EAPI void evas_object_textblock_replace_char_set(Evas_Object *obj, const char *ch);
 
@@ -930,7 +925,7 @@ EAPI void evas_object_textblock_replace_char_set(Evas_Object *obj, const char *c
  *
  * @return The charset name.
  *
- * @ingroup Efl_Canvas_Text
+ * @ingroup Efl_Canvas_Textblock
  */
 EAPI const char *evas_object_textblock_replace_char_get(const Evas_Object *obj);
 
@@ -945,7 +940,7 @@ EAPI const char *evas_object_textblock_replace_char_get(const Evas_Object *obj);
  *
  * @since 1.1
  *
- * @ingroup Efl_Canvas_Text
+ * @ingroup Efl_Canvas_Textblock
  */
 EAPI void evas_object_textblock_valign_set(Evas_Object *obj, double align);
 
@@ -960,7 +955,7 @@ EAPI void evas_object_textblock_valign_set(Evas_Object *obj, double align);
  *
  * @since 1.1
  *
- * @ingroup Efl_Canvas_Text
+ * @ingroup Efl_Canvas_Textblock
  */
 EAPI double evas_object_textblock_valign_get(const Evas_Object *obj);
 
@@ -1023,7 +1018,7 @@ EAPI void evas_textblock_cursor_line_char_last(Evas_Textblock_Cursor *cur);
  * Set the cursor pos.
  *
  * @param cur the cursor to be set.
- * @param pos the pos to set.
+ * @param _pos the pos to set.
  */
 EAPI void evas_textblock_cursor_pos_set(Evas_Textblock_Cursor *cur, int _pos);
 
@@ -1056,7 +1051,107 @@ EAPI void evas_textblock_cursor_char_delete(Evas_Textblock_Cursor *cur);
  * @ingroup Evas_Textblock
  */
 EAPI Evas_Textblock_Cursor *evas_object_textblock_cursor_get(const Evas_Object *obj);
-#include "canvas/efl_canvas_text_eo.legacy.h"
+
+
+
+/* TEXT BLOCK FIT OPTIONS FLAGS*/
+#define TEXTBLOCK_FIT_MODE_NONE        0x0000
+#define TEXTBLOCK_FIT_MODE_WIDTH       0x0001
+#define TEXTBLOCK_FIT_MODE_HEIGHT      0x0002
+#define TEXTBLOCK_FIT_MODE_ALL         0x0003
+
+/* TEXT BLOCK ERROR CODES*/
+/* FIXME this hould go to other public place*/
+#define EVAS_ERROR_SUCCESS              0x0000
+#define EVAS_ERROR_INVALID_PARAM        0x0001
+#define EVAS_ERROR_NO_MEMORY            0x0002
+#define EVAS_ERROR_INVALID_OPERATION    0x0003
+
+
+/** Get the object's content fit options.
+ *
+ * @param obj The textblock object.
+ * @param[out] p_options content fitting options.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_options_get(const Evas_Object *obj,  unsigned int * p_options);
+
+/** Set the object's content fit options.
+ *
+ * @param obj The textblock object.
+ * @param[in] options content fitting options.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_options_set(Evas_Object *obj,  unsigned int options);
+
+/** Get the object's max and min font sizes used for fitting content.
+ *
+ * @param obj The textblock object.
+ * @param[out] p_min_font_size min font size used when fitting content.
+ * @param[out] p_max_font_size max font size used when fitting content.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_size_range_get(const Evas_Object *obj,  unsigned int *p_min_font_size, unsigned int *p_max_font_size);
+
+/** Set the object's max and min font sizes used for fitting content.
+ *
+ * @param obj The textblock object.
+ * @param[in] min_font_size min font size used when fitting content.
+ * @param[in] max_font_size max font size used when fitting content.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_size_range_set(Evas_Object *obj,  unsigned int min_font_size, unsigned int max_font_size);
+
+
+/** Get the object's fitting step size when trying fonts between min font size and
+ *  max font size.
+ *
+ * @param obj The textblock object.
+ * @param[out] p_step_size step jumps between min and max font size.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_step_size_get(const Evas_Object *obj,  unsigned int *p_step_size);
+
+
+/** Set the object's fitting step size when trying fonts between min font size and
+ *  max font size.
+ *
+ * @param obj The textblock object.
+ * @param[out] step_size step jumps between min and max font size.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_step_size_set(Evas_Object *obj,  unsigned int step_size);
+
+/** Get copy of the object's fitting font size array used internally
+ *
+ * @param obj The textblock object.
+ * @param[out] p_size_array pointer to size array (passing NULL will ignore filling array).
+ * @param[out] p_size_array_len the length of internall font sizes array.
+ * @param[out] request_size_array request to fill specific amount in p_size_array.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_size_array_get(const Evas_Object *obj,  unsigned int *p_size_array, size_t *p_size_array_len,size_t request_size_array);
+
+/** Set the object's fitting font size array that will be used internally
+ *  Changing fitting step_size,min_font_size,max_font size will generate new array
+ *  Internall array will be sorted
+ *
+ * @param obj The textblock object.
+ * @param[in] p_size_array pointer to font sizes array.
+ * @param[in] size_array_len the length passed font sizes array.
+ * @return Returns error code.
+ */
+EAPI int evas_textblock_fit_size_array_set(Evas_Object *obj,  const unsigned int *p_size_array, size_t size_array_len);
+
+
+
+
+
+
+
+
+
+#include "canvas/efl_canvas_textblock_eo.legacy.h"
 /**
  * @}
  */
